diff data/model/DenseTimeValueModel.h @ 1126:39019ce29178 tony-2.0-integration

Merge through to branch for Tony 2.0
author Chris Cannam
date Thu, 20 Aug 2015 14:54:21 +0100
parents 4d9816ba0ebe
children 54af1e21705c
line wrap: on
line diff
--- a/data/model/DenseTimeValueModel.h	Fri Aug 14 18:16:14 2015 +0100
+++ b/data/model/DenseTimeValueModel.h	Thu Aug 20 14:54:21 2015 +0100
@@ -57,32 +57,22 @@
 
     /**
      * Get the specified set of samples from the given channel of the
-     * model in single-precision floating-point format.  Return the
-     * number of samples actually retrieved.
+     * model in single-precision floating-point format. Returned
+     * vector may have fewer samples than requested, if the end of
+     * file was reached.
+     *
      * If the channel is given as -1, mix all available channels and
      * return the result.
      */
-    virtual sv_frame_t getData(int channel, sv_frame_t start, sv_frame_t count,
-                               float *buffer) const = 0;
+    virtual std::vector<float> getData(int channel, sv_frame_t start, sv_frame_t count) const = 0;
 
     /**
      * Get the specified set of samples from the given channel of the
      * model in double-precision floating-point format.  Return the
      * number of samples actually retrieved.
      * If the channel is given as -1, mix all available channels and
      * return the result.
      */
-    virtual sv_frame_t getData(int channel, sv_frame_t start, sv_frame_t count,
-                               double *buffer) const = 0;
-    
-    /**
-     * Get the specified set of samples from given contiguous range
-     * of channels of the model in single-precision floating-point
-     * format.  Return the number of sample frames actually retrieved.
-     */
-    virtual sv_frame_t getData(int fromchannel, int tochannel,
-                               sv_frame_t start, sv_frame_t count,
-                               float **buffers) const = 0;
+    virtual std::vector<std::vector<float>> getMultiChannelData(int fromchannel, int tochannel, sv_frame_t start, sv_frame_t count) const = 0;
 
     virtual bool canPlay() const { return true; }
     virtual QString getDefaultPlayClipId() const { return ""; }
@@ -57,32 +57,22 @@
 
     /**
-     * Get the specified set of samples from the given channel of the
-     * model in double-precision floating-point format.  Return the
-     * number of samples actually retrieved.
-     * If the channel is given as -1, mix all available channels and
-     * return the result.
+     * Get the specified set of samples from given contiguous range of
+     * channels of the model in single-precision floating-point
+     * format. Returned vector may have fewer samples than requested,
+     * if the end of file was reached.
      */